"""
netdisco.util.ssh
~~~~~~~~~~~~~~~~~

This module provides a netmiko connection handler using
the credentials in device_auth.
"""

import os
from netmiko import ConnectHandler

from netdisco.util.config import setting
from netdisco.util.job import job

if 'ND2_FSM_TEMPLATES' in os.environ:
    os.environ['NET_TEXTFSM'] = os.environ['ND2_FSM_TEMPLATES']

device_auth_setting = setting('device_auth')
if not isinstance(device_auth_setting, list):
    raise Exception('device_auth is not a list')
if len(device_auth_setting) != 1:
    raise Exception('device_auth for cli is not one entry only')

device_auth = device_auth_setting[0]
if not isinstance(device_auth, dict):
    raise Exception('device_auth[0] is not a dictionary')

target = {
    'host': job.device,
    'username': device_auth['username'],
    'password': device_auth['password'],
    'device_type': device_auth['device_type'],
}
net_connect = ConnectHandler(**target)



"""
netdisco.util.status
~~~~~~~~~~~~~~~~~~~~

This module provides a Status class which models the return code and message
of a Python worklet along with convenience methods to set the status. A fresh
instance of the Status class has an empty log message and null (empty string)
status.
"""

from dataclasses import dataclass


@dataclass(frozen=True)
class StatusManager:
    status: str = ''
    log: str = ''

    def is_ok(self) -> bool:
        return True if self.status == 'done' else False

    def not_ok(self) -> bool:
        return not self.is_ok()

    def level(self) -> int:
        return (
            4
            if self.status == 'error'
            else 3
            if self.status == 'done'
            else 2
            if self.status == 'defer'
            else 1
            if self.status == 'info'
            else 0
        )

    def error(self, msg):
        object.__setattr__(self, 'status', 'error')
        object.__setattr__(self, 'log', msg)

    def done(self, msg):
        object.__setattr__(self, 'status', 'done')
        object.__setattr__(self, 'log', msg)

    def defer(self, msg):
        object.__setattr__(self, 'status', 'defer')
        object.__setattr__(self, 'log', msg)

    def info(self, msg):
        object.__setattr__(self, 'status', 'info')
        object.__setattr__(self, 'log', msg)

    def reset(self):
        object.__setattr__(self, 'status', '')
        object.__setattr__(self, 'log', '')


status = StatusManager()
